summaryrefslogtreecommitdiffstats
path: root/tdecore/network/kbufferedsocket.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/network/kbufferedsocket.h')
-rw-r--r--tdecore/network/kbufferedsocket.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/tdecore/network/kbufferedsocket.h b/tdecore/network/kbufferedsocket.h
index 93bee08f3..60ad3e81d 100644
--- a/tdecore/network/kbufferedsocket.h
+++ b/tdecore/network/kbufferedsocket.h
@@ -31,12 +31,12 @@
#include "kstreamsocket.h"
#include <tdelibs_export.h>
-class KIOBufferBase;
+class TDEIOBufferBase;
namespace KNetwork {
-class KBufferedSocketPrivate;
-/** @class KBufferedSocket kbufferedsocket.h kbufferedsocket.h
+class TDEBufferedSocketPrivate;
+/** @class TDEBufferedSocket kbufferedsocket.h kbufferedsocket.h
* @brief Buffered stream sockets.
*
* This class allows the user to create and operate buffered stream sockets
@@ -52,10 +52,10 @@ class KBufferedSocketPrivate;
* imposed by Qt's TQSocketNotifier. If you want to use a socket
* in an auxiliary thread, please use KStreamSocket.
*
- * @see KNetwork::KStreamSocket, KNetwork::KServerSocket
+ * @see KNetwork::KStreamSocket, KNetwork::TDEServerSocket
* @author Thiago Macieira <[email protected]>
*/
-class TDECORE_EXPORT KBufferedSocket: public KStreamSocket
+class TDECORE_EXPORT TDEBufferedSocket: public KStreamSocket
{
Q_OBJECT
@@ -68,18 +68,18 @@ public:
* @param parent the parent object for this object
* @param name the internal name for this object
*/
- KBufferedSocket(const TQString& node = TQString::null, const TQString& service = TQString::null,
+ TDEBufferedSocket(const TQString& node = TQString::null, const TQString& service = TQString::null,
TQObject* parent = 0L, const char *name = 0L);
/**
* Destructor.
*/
- virtual ~KBufferedSocket();
+ virtual ~TDEBufferedSocket();
/**
* Be sure to catch new devices.
*/
- virtual void setSocketDevice(KSocketDevice* device);
+ virtual void setSocketDevice(TDESocketDevice* device);
protected:
/**
@@ -122,7 +122,7 @@ public:
*
* The @p from parameter is always set to @ref peerAddress()
*/
- virtual TQT_TQIO_LONG tqreadBlock(char *data, TQT_TQIO_ULONG maxlen, KSocketAddress& from);
+ virtual TQT_TQIO_LONG tqreadBlock(char *data, TQT_TQIO_ULONG maxlen, TDESocketAddress& from);
/**
* Peeks data from the socket.
@@ -135,7 +135,7 @@ public:
*
* The @p from parameter is always set to @ref peerAddress()
*/
- virtual TQ_LONG peekBlock(char *data, TQ_ULONG maxlen, KSocketAddress &from);
+ virtual TQ_LONG peekBlock(char *data, TQ_ULONG maxlen, TDESocketAddress &from);
/**
* Writes data to the socket.
@@ -148,7 +148,7 @@ public:
*
* The @p to parameter is discarded.
*/
- virtual TQT_TQIO_LONG tqwriteBlock(const char *data, TQT_TQIO_ULONG len, const KSocketAddress& to);
+ virtual TQT_TQIO_LONG tqwriteBlock(const char *data, TQT_TQIO_ULONG len, const TDESocketAddress& to);
/**
* Catch changes.
@@ -168,7 +168,7 @@ public:
/**
* Retrieves the input buffer object.
*/
- KIOBufferBase* inputBuffer();
+ TDEIOBufferBase* inputBuffer();
/**
* Sets the use of output buffering.
@@ -178,7 +178,7 @@ public:
/**
* Retrieves the output buffer object.
*/
- KIOBufferBase* outputBuffer();
+ TDEIOBufferBase* outputBuffer();
/**
* Returns the length of the output buffer.
@@ -240,10 +240,10 @@ signals:
void bytesWritten(int bytes);
private:
- KBufferedSocket(const KBufferedSocket&);
- KBufferedSocket& operator=(const KBufferedSocket&);
+ TDEBufferedSocket(const TDEBufferedSocket&);
+ TDEBufferedSocket& operator=(const TDEBufferedSocket&);
- KBufferedSocketPrivate *d;
+ TDEBufferedSocketPrivate *d;
public:
// KDE4: remove this function
@@ -253,7 +253,7 @@ public:
*
* This function is provided to ease porting from KExtendedSocket,
* which required a call to reset() in order to be able to connect again
* using the same device. This is not necessary in KBufferedSocket any more.
*/
#ifdef USE_QT3
inline void reset()
@@ -253,7 +253,7 @@ public:
* This function is provided to ease porting from KExtendedSocket,
* which required a call to reset() in order to be able to connect again
- * using the same device. This is not necessary in KBufferedSocket any more.
+ * using the same device. This is not necessary in TDEBufferedSocket any more.
*/
#ifdef USE_QT3